@@ -16,6 +16,7 @@ module Language.Javascript.JMacro.QQ(jmacro,jmacroE,parseJM,parseJME) where
 import Prelude hiding (tail, init, head, last, minimum, maximum, foldr1, foldl1, (!!), read)
 import Control.Applicative hiding ((<|>),many,optional)
 import Control.Arrow(first)
+import Control.Monad (ap, return, liftM2, liftM3, when, mzero, guard)
 import Control.Monad.State.Strict
 import Data.Char(digitToInt, toLower, isUpper)
 import Data.List(isPrefixOf, sort)
@@ -240,7 +241,9 @@ jsLang = javaStyle {
            P.opLetter = oneOf "|+-/*%<>&^.?=!~:@",
            P.commentLine = "//",
            P.commentStart = "/*",
-           P.commentEnd = "*/"}
+           P.commentEnd = "*/",
+           P.caseSensitive = True
+           }
 
 identifierWithBang = P.identifier $ P.makeTokenParser $ jsLang {P.identStart = letter <|> oneOf "_$!"}
 
